@@ -37,7 +37,7 @@ const captureReport = async (): Promise<void> => {
     name: 'Centreon Web pages',
   });
 
-  execSync(`docker cp ./features.json ${process.env.DOCKER_NAME || 'centreon-dev'}:/usr/share/centreon/config/features.json`);
+  execSync(`docker compose -f ../../.github/docker/docker-compose.yml cp ./features.json web:/usr/share/centreon/config/features.json`);
 
   const navigate = async ({ url, name }: NavigateProps): Promise<void> => {
     await flow.navigate(url, { formFactor: 'desktop', name, ...baseConfig });
@@ -108,4 +108,4 @@ const captureReport = async (): Promise<void> => {
   createReportFile(flow.generateReport());
 };
 
-captureReport();
\ No newline at end of file
+captureReport();
