@@ -116,15 +116,20 @@ fixCentreonCronPermissions() {
   chmod 0755 /usr/share/centreon/cron/outdated-token-removal.php
   chown -R centreon:centreon /usr/share/centreon/cron/outdated-token-removal.php
 
-  # Update log file permissions which has been potentially created by centreon user
-  APP_LOG_FILE="/var/log/centreon/centreon-web.log"
-  if [ -f "$APP_LOG_FILE" ]; then
-    if [ "$1" = "rpm" ]; then
-      chown apache:apache "$APP_LOG_FILE"
-    else
-      chown www-data:www-data "$APP_LOG_FILE"
+  # Update log files permissions which have been potentially created by centreon user
+  LOG_FILES=(
+    "/var/log/centreon/centreon-web.log"
+    "/var/log/centreon/centreon-tokens.log"
+  )
+  for LOG_FILE in "${LOG_FILES[@]}"; do
+    if [ -f "$LOG_FILE" ]; then
+      if [ "$1" = "rpm" ]; then
+        chown apache:apache "$LOG_FILE"
+      else
+        chown www-data:www-data "$LOG_FILE"
+      fi
     fi
-  fi
+  done
 }
 
 package_type="rpm"
@@ -149,7 +154,7 @@ case "$action" in
     manageLocales $package_type
     manageApacheAndPhpFpm $package_type
     fixSymfonyCacheRights $package_type
-    fixCentreonCronPermissions
+    fixCentreonCronPermissions $package_type
     ;;
   "2" | "upgrade")
     manageUsersAndGroups $package_type
