@@ -63,7 +63,7 @@ class ConfigurationExporter extends ExporterServiceAbstract
     /**
      * Import data.
      *
-     * @param \CentreonRemote\Infrastructure\Export\ExportManifest $manifest
+     * @param ExportManifest $manifest
      */
     public function import(ExportManifest $manifest): void
     {
@@ -142,6 +142,14 @@ class ConfigurationExporter extends ExporterServiceAbstract
         return 40;
     }
 
+    /**
+     * @return string
+     */
+    public static function getName(): string
+    {
+        return static::NAME;
+    }
+
     /**
      * Copy directory recursively.
      *
