@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2019 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,9 +26,10 @@ interface ExportParserInterface
     /**
      * @param string $filename
      * @param callable|null $macros
+     *
      * @return array<mixed>
      */
-    public function parse(string $filename, callable $macros = null): array;
+    public function parse(string $filename, ?callable $macros = null): array;
 
     /**
      * @param array<mixed> $input
