@@ -25,6 +25,7 @@ namespace Core\Application\Configuration\Notification\Repository;
 
 use Core\Domain\Configuration\Notification\Model\NotifiedContact;
 use Core\Domain\Configuration\Notification\Model\NotifiedContactGroup;
+use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 interface ReadServiceNotificationRepositoryInterface
 {
@@ -36,6 +37,15 @@ interface ReadServiceNotificationRepositoryInterface
      */
     public function findNotifiedContactsById(int $hostId, int $serviceId): array;
 
+    /**
+     * @param int $hostId
+     * @param int $serviceId
+     * @param AccessGroup[] $accessGroups
+     *
+     * @return NotifiedContact[]
+     */
+    public function findNotifiedContactsByIdAndAccessGroups(int $hostId, int $serviceId, array $accessGroups): array;
+
     /**
      * @param int $hostId
      * @param int $serviceId
@@ -43,4 +53,13 @@ interface ReadServiceNotificationRepositoryInterface
      * @return NotifiedContactGroup[]
      */
     public function findNotifiedContactGroupsById(int $hostId, int $serviceId): array;
+
+    /**
+     * @param int $hostId
+     * @param int $serviceId
+     * @param AccessGroup[] $accessGroups
+     *
+     * @return NotifiedContactGroup[]
+     */
+    public function findNotifiedContactGroupsByIdAndAccessGroups(int $hostId, int $serviceId, array $accessGroups): array;
 }
