@@ -239,9 +239,9 @@ class DbReadVaultConfigurationRepository extends AbstractRepositoryDRB implement
                         LIMIT 1
                     SQL
             )
-        );
+        ) ?: null;
 
-        if (! ($record = $statement->fetch(\PDO::FETCH_ASSOC))) {
+        if (! ($record = $statement?->fetch(\PDO::FETCH_ASSOC))) {
             return null;
         }
 
