@@ -30,7 +30,7 @@ use Core\Security\AccessGroup\Application\Repository\ReadAccessGroupRepositoryIn
 use Core\Severity\RealTime\Application\Repository\ReadSeverityRepositoryInterface;
 use Core\Severity\RealTime\Domain\Model\Severity;
 
-class FindSeverity
+final class FindSeverity
 {
     use LoggerTrait;
 
