@@ -50,9 +50,8 @@ const getCentreonStableMinorVersions = (
     commandResult = cy
       .execInContainer({
         command: [
-          `mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak`,
-          `mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak`,
-          `apt-get update`
+          'for i in $( ls /etc/apt/sources.list.d/centreon*{unstable,testing}* ); do mv $i $i.disabled; done',
+          'apt-get update'
         ],
         name: 'web'
       })
@@ -80,9 +79,8 @@ const getCentreonStableMinorVersions = (
     } else {
       cy.execInContainer({
         command: [
-          `mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list`,
-          `mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list`,
-          `apt-get update`
+          'for i in $( ls /etc/apt/sources.list.d/centreon*{unstable,testing}*.disabled ); do mv $i "$(echo $i | sed -r \'s/.disabled//\')"; done',
+          'apt-get update'
         ],
         name: 'web'
       });
@@ -209,9 +207,8 @@ const installCentreon = (version: string): Cypress.Chainable => {
 
     cy.execInContainer({
       command: [
-        `mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak`,
-        `mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak`,
-        `apt-get update`,
+        'for i in $( ls /etc/apt/sources.list.d/centreon*{unstable,testing}* ); do mv $i $i.disabled; done',
+        'apt-get update',
         `apt-get install -y ${packagesToInstall.join(' ')}`,
         `mkdir -p /usr/lib/centreon-connector`,
         `echo "date.timezone = Europe/Paris" > /etc/php/${phpVersion}/mods-available/timezone.ini`,
@@ -222,10 +219,9 @@ const installCentreon = (version: string): Cypress.Chainable => {
         `systemctl restart php${phpVersion}-fpm`,
         `systemctl restart apache2`,
         `mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"`,
-        `mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list`,
-        `mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list`,
-        `apt-get update`,
-        `usermod -a -G centreon-broker www-data`
+        'for i in $( ls /etc/apt/sources.list.d/centreon*{unstable,testing}*.disabled ); do mv $i "$(echo $i | sed -r \'s/.disabled//\')"; done',
+        'apt-get update',
+        'usermod -a -G centreon-broker www-data' // temporary fix (MON-20769)
       ],
       name: 'web'
     });
