@@ -33,18 +33,13 @@
  *
  */
 
-require_once __DIR__ . "/centreon_configuration_objects.class.php";
+require_once dirname(__FILE__) . "/centreon_configuration_objects.class.php";
 
-/**
- * Class
- *
- * @class CentreonConfigurationBroker
- */
 class CentreonConfigurationBroker extends CentreonConfigurationObjects
 {
     /**
-     * @throws \Exception
-     * @return false|string
+     * @return array
+     * @throws Exception
      */
     public function getBlock()
     {
@@ -89,10 +84,19 @@ class CentreonConfigurationBroker extends CentreonConfigurationObjects
         }
         textdomain('messages');
 
-        // Smarty template initialization
-        $tpl = SmartyCentreon::createSmartyTemplate(
-            _CENTREON_PATH_ . '/www/include/configuration/configCentreonBroker/'
-        );
+        /*
+         * Smarty template Init
+         */
+        $libDir = __DIR__ . "/../../../GPL_LIB";
+        $tpl = new \SmartyBC();
+        $tpl->setTemplateDir(_CENTREON_PATH_ . '/www/include/configuration/configCentreonBroker/');
+        $tpl->setCompileDir($libDir . '/SmartyCache/compile');
+        $tpl->setConfigDir($libDir . '/SmartyCache/config');
+        $tpl->setCacheDir($libDir . '/SmartyCache/cache');
+        $tpl->addPluginsDir($libDir . '/smarty-plugins');
+        $tpl->loadPlugin('smarty_function_eval');
+        $tpl->setForceCompile(true);
+        $tpl->setAutoLiteral(false);
 
         /*
          * Apply a template definition
