@@ -694,20 +694,6 @@ class CentreonAPI
         return $res[1];
     }
 
-    /**
-     *
-     * Check that parameters are not empty
-     * @param varchar $str
-     */
-    private function checkParameters($str)
-    {
-        if (!isset($this->options["v"]) || $this->options["v"] == "") {
-            print "No options defined.\n";
-            $this->return_code = 1;
-            return 1;
-        }
-    }
-
     /**
      *
      * Init XML Flow
@@ -807,28 +793,37 @@ class CentreonAPI
         $handle = fopen($filename, 'r');
         if ($handle) {
             $i = 0;
-            while ($string = fgets($handle)) {
+            while (($string = fgets($handle)) !== false) {
                 $i++;
-                $tab = preg_split('/;/', $string);
-                if (strlen(trim($string)) != 0 && !preg_match('/^\{OBJECT_TYPE\}/', $string)) {
-                    $this->object = trim($tab[0]);
-                    $this->action = trim($tab[1]);
-                    $this->variables = trim(substr($string, strlen($tab[0] . ";" . $tab[1] . ";")));
-                    if ($this->debug == 1) {
-                        print "Object : " . $this->object . "\n";
-                        print "Action : " . $this->action . "\n";
-                        print "VARIABLES : " . $this->variables . "\n\n";
-                    }
-                    try {
-                        $this->launchActionForImport();
-                    } catch (CentreonClapiException $e) {
-                        echo "Line $i : " . $e->getMessage() . "\n";
-                    } catch (\Exception $e) {
-                        echo "Line $i : " . $e->getMessage() . "\n";
-                    }
-                    if ($this->return_code) {
-                        $globalReturn = 1;
-                    }
+
+                $string = trim($string);
+                if (
+                    $string === ''
+                    || str_starts_with($string, '#')
+                    || str_starts_with($string, '{OBJECT_TYPE}')
+                ) {
+                    continue;
+                }
+
+                $tab = explode(';', $string, 3);
+                $this->object = trim($tab[0]);
+                $this->action = trim($tab[1]);
+                $this->variables = trim($tab[2]);
+
+                if ($this->debug == 1) {
+                    print "Object : " . $this->object . "\n";
+                    print "Action : " . $this->action . "\n";
+                    print "VARIABLES : " . $this->variables . "\n\n";
+                }
+                try {
+                    $this->launchActionForImport();
+                } catch (CentreonClapiException $e) {
+                    echo "Line $i : " . $e->getMessage() . "\n";
+                } catch (\Exception $e) {
+                    echo "Line $i : " . $e->getMessage() . "\n";
+                }
+                if ($this->return_code) {
+                    $globalReturn = 1;
                 }
             }
             fclose($handle);
@@ -1033,13 +1028,6 @@ class CentreonAPI
         $res = $this->DB->query("SELECT * FROM informations WHERE `key` = 'version'");
         $data = $res->fetchRow();
         print "Centreon version " . $data["value"] . "\n";
-        $res = $this->DB->query("SELECT mod_release FROM modules_informations WHERE name = 'centreon-clapi'");
-        $clapiVersion = 'undefined';
-        if ($res->rowCount()) {
-            $data = $res->fetchRow();
-            $clapiVersion = $data['mod_release'];
-        }
-        print "Centreon CLAPI version " . $clapiVersion . "\n";
     }
 
     /**     * *****************************************************
