@@ -1135,9 +1135,6 @@ class CentreonHost extends CentreonObject
             }
             $this->deployServices($hostId, $templateId);
         }
-
-        $aclObj = new CentreonACL($this->dependencyInjector);
-        $aclObj->reload(false);
     }
 
     /**
@@ -1156,6 +1153,9 @@ class CentreonHost extends CentreonObject
             throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ":" . $hostName);
         }
         $this->deployServices($hostId);
+
+        $aclObj = new CentreonACL($this->dependencyInjector);
+        $aclObj->reload(true);
     }
 
     /**
