@@ -21,7 +21,7 @@ export const getDashboardAccessRightsContactGroupEndpoint = (
 
 export const dashboardsContactsEndpoint = `/configuration/dashboards/contacts`;
 
-export const dashboardsContactGroupsEndpoint = `${baseEndpoint}/configuration/dashboards/contactgroups`;
+export const dashboardsContactGroupsEndpoint = `/configuration/dashboards/contactgroups`;
 
 export const playlistsEndpoint = `/configuration/dashboards/playlists`;
 
