@@ -13,9 +13,9 @@ type Props = {
 const ActionMenuItem = ({
   permitted,
   label,
-  onClick,
   testId,
-  disabled,
+  onClick,
+  disabled
 }: Props): JSX.Element => {
   const { t } = useTranslation();
 
