@@ -7,6 +7,7 @@ import { animated, useTransition } from '@react-spring/web';
 
 import { styled } from '@mui/material';
 
+import { featureFlagsDerivedAtom } from '@centreon/ui-context';
 import { PageSkeleton, useMemoComponent } from '@centreon/ui';
 
 import internalPagesRoutes from '../../reactRoutes';
@@ -17,6 +18,7 @@ import { FederatedModule } from '../../federatedModules/models';
 import { Remote } from '../../federatedModules/Load';
 import routeMap from '../../reactRoutes/routeMap';
 import { deprecatedRoutes } from '../../reactRoutes/deprecatedRoutes';
+import { childrenComponentsMapping } from '../../federatedModules/childrenComponentsMapping';
 
 import DeprecatedRoute from './DeprecatedRoute';
 
@@ -56,6 +58,12 @@ interface IsAllowedPageProps {
   path?: string;
 }
 
+interface GetExternalPageRoutesProps {
+  allowedPages?: Array<string | Array<string>>;
+  featureFlags: Record<string, boolean>;
+  federatedModules: Array<FederatedModule>;
+}
+
 const isAllowedPage = ({ path, allowedPages }: IsAllowedPageProps): boolean =>
   flatten(allowedPages || []).some((allowedPage) =>
     path?.includes(allowedPage)
@@ -63,8 +71,9 @@ const isAllowedPage = ({ path, allowedPages }: IsAllowedPageProps): boolean =>
 
 const getExternalPageRoutes = ({
   allowedPages,
-  federatedModules
-}): Array<JSX.Element> => {
+  federatedModules,
+  featureFlags
+}: GetExternalPageRoutesProps): Array<Array<JSX.Element | null>> => {
   return federatedModules?.map(
     ({
       federatedPages,
@@ -73,31 +82,59 @@ const getExternalPageRoutes = ({
       moduleName,
       remoteUrl
     }) => {
-      return federatedPages?.map(({ component, route }) => {
-        if (not(isAllowedPage({ allowedPages, path: route }))) {
-          return null;
-        }
+      const filteredPagesByFeatureFlag = (federatedPages || [])?.filter(
+        ({ featureFlag }) => {
+          if (isNil(featureFlag)) {
+            return true;
+          }
 
-        return (
-          <Route
-            element={
-              <PageContainer>
-                <BreadcrumbTrail path={route} />
-                <Remote
-                  component={component}
-                  key={component}
-                  moduleFederationName={moduleFederationName}
-                  moduleName={moduleName}
-                  remoteEntry={remoteEntry}
-                  remoteUrl={remoteUrl}
-                />
-              </PageContainer>
-            }
-            key={route}
-            path={route}
-          />
-        );
-      });
+          return featureFlags[featureFlag];
+        }
+      );
+
+      return filteredPagesByFeatureFlag.map(
+        ({ component, route, children }) => {
+          if (not(isAllowedPage({ allowedPages, path: route }))) {
+            return null;
+          }
+
+          const ChildrenComponent: ((props) => JSX.Element) | null | undefined =
+            children ? childrenComponentsMapping[children] : undefined;
+
+          return (
+            <Route
+              element={
+                <PageContainer>
+                  <BreadcrumbTrail path={route} />
+                  {ChildrenComponent ? (
+                    <Remote
+                      component={component}
+                      key={component}
+                      moduleFederationName={moduleFederationName}
+                      moduleName={moduleName}
+                      remoteEntry={remoteEntry}
+                      remoteUrl={remoteUrl}
+                    >
+                      {(props): JSX.Element => <ChildrenComponent {...props} />}
+                    </Remote>
+                  ) : (
+                    <Remote
+                      component={component}
+                      key={component}
+                      moduleFederationName={moduleFederationName}
+                      moduleName={moduleName}
+                      remoteEntry={remoteEntry}
+                      remoteUrl={remoteUrl}
+                    />
+                  )}
+                </PageContainer>
+              }
+              key={route}
+              path={route}
+            />
+          );
+        }
+      );
     }
   );
 };
@@ -117,6 +154,8 @@ const ReactRouterContent = ({
 }: Props): JSX.Element => {
   const parameters = useParams();
 
+  const featureFlags = useAtomValue(featureFlagsDerivedAtom);
+
   return useMemoComponent({
     Component: (
       <Suspense fallback={<PageSkeleton />}>
@@ -153,7 +192,11 @@ const ReactRouterContent = ({
               />
             );
           })}
-          {getExternalPageRoutes({ allowedPages, federatedModules })}
+          {getExternalPageRoutes({
+            allowedPages,
+            featureFlags,
+            federatedModules
+          })}
           {externalPagesFetched && (
             <Route element={<NotFoundPage />} path="*" />
           )}
