@@ -19,8 +19,13 @@
  *
  */
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\Exception\ConnectionException;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
 use Adaptation\Log\LoggerPassword;
+use Core\Common\Domain\Exception\CollectionException;
 use Core\Common\Domain\Exception\RepositoryException;
+use Core\Common\Domain\Exception\ValueObjectException;
 
 require_once __DIR__ . '/../../../class/centreonContact.class.php';
 require_once __DIR__ . '/../../../class/centreonAuth.class.php';
@@ -72,23 +77,23 @@ function testAliasExistence($alias = null)
     }
 }
 
-function updateNotificationOptions($contact_id)
+function updateNotificationOptions($userIdConnected)
 {
     global $form, $pearDB;
 
-    $pearDB->query("DELETE FROM contact_param
-        WHERE cp_contact_id = " . $pearDB->escape($contact_id) . "
+    $pearDB->query('DELETE FROM contact_param
+        WHERE cp_contact_id = ' . $pearDB->escape($userIdConnected) . "
         AND cp_key LIKE 'monitoring%notification%'");
     $data = $form->getSubmitValues();
     foreach ($data as $k => $v) {
-        if (preg_match("/^monitoring_(host|svc)_notification/", $k)) {
-            $query = "INSERT INTO contact_param (cp_key, cp_value, cp_contact_id) " .
-                "VALUES ('" . $pearDB->escape($k) . "', '1', " . $pearDB->escape($contact_id) . ")";
+        if (preg_match('/^monitoring_(host|svc)_notification/', $k)) {
+            $query = 'INSERT INTO contact_param (cp_key, cp_value, cp_contact_id) '
+                . "VALUES ('" . $pearDB->escape($k) . "', '1', " . $pearDB->escape($userIdConnected) . ')';
             $pearDB->query($query);
-        } elseif (preg_match("/^monitoring_sound/", $k)) {
-            $query = "INSERT INTO contact_param (cp_key, cp_value, cp_contact_id) " .
-                "VALUES ('" . $pearDB->escape($k) . "', '" . $pearDB->escape($v) . "', " .
-                $pearDB->escape($contact_id) . ")";
+        } elseif (preg_match('/^monitoring_sound/', $k)) {
+            $query = 'INSERT INTO contact_param (cp_key, cp_value, cp_contact_id) '
+                . "VALUES ('" . $pearDB->escape($k) . "', '" . $pearDB->escape($v) . "', "
+                . $pearDB->escape($userIdConnected) . ')';
             $pearDB->query($query);
         }
     }
@@ -96,35 +101,35 @@ function updateNotificationOptions($contact_id)
 }
 
 /**
- * @param $contact_id
- *
- * @throws InvalidArgumentException
- * @throws PDOException
  * @throws RepositoryException
- * @return void
  */
-function updateContactInDB($contact_id = null): void
+function updateContactByMyAccountInDB(mixed $userIdConnected): void
 {
-    if (!$contact_id) {
-        return;
+    $userIdConnected = (int) $userIdConnected;
+
+    if (! $userIdConnected > 0) {
+        throw new RepositoryException(
+            message: 'Invalid connected user ID provided to update contact from my account page for contact id ' . $userIdConnected,
+            context: ['contact_id' => $userIdConnected]
+        );
     }
-    updateContact($contact_id);
-    updateNotificationOptions($contact_id);
+
+    updateContactByMyAccount($userIdConnected);
+    updateNotificationOptions($userIdConnected);
 }
 
 /**
- * @param $contactId
- *
- * @throws PDOException
  * @throws RepositoryException
- * @return void
  */
-function updateContact($contactId = null): void
+function updateContactByMyAccount(int $userIdConnected): void
 {
     global $form, $pearDB, $centreon;
 
-    if (!$contactId) {
-        return;
+    if (! $userIdConnected > 0) {
+        throw new RepositoryException(
+            message: 'Invalid connected user ID provided to update contact from my account page for contact id ' . $userIdConnected,
+            context: ['contact_id' => $userIdConnected]
+        );
     }
 
     $submitValues = $form->getSubmitValues();
@@ -152,58 +157,71 @@ function updateContact($contactId = null): void
           'contact_autologin_key = :contactAutologinKey';
     $rq .= ' WHERE contact_id = :contactId';
 
-    $stmt = $pearDB->prepare($rq);
-    $stmt->bindValue(':contactName', $submitValues['contact_name'], PDO::PARAM_STR);
-    $stmt->bindValue(':contactAlias', $submitValues['contact_alias'], PDO::PARAM_STR);
-    $stmt->bindValue(':contactLang', $submitValues['contact_lang'], PDO::PARAM_STR);
-    $stmt->bindValue(
-        ':contactEmail',
-        ! empty($submitValues['contact_email']) ? $submitValues['contact_email'] : null,
-        PDO::PARAM_STR
-    );
-    $stmt->bindValue(
-        ':contactPager',
-        ! empty($submitValues['contact_pager']) ? $submitValues['contact_pager'] : null,
-        PDO::PARAM_STR
-    );
-    $stmt->bindValue(
-        ':contactAutologinKey',
-        ! empty($submitValues['contact_autologin_key']) ? $submitValues['contact_autologin_key'] : null,
-        PDO::PARAM_STR
-    );
-    $stmt->bindValue(
-        ':contactLocation',
-        ! empty($submitValues['contact_location']) ? $submitValues['contact_location'] : null,
-        PDO::PARAM_INT
-    );
-    $stmt->bindValue(':defaultPage', ! empty($submitValues['default_page']) ? $submitValues['default_page'] : null, PDO::PARAM_INT);
-    $stmt->bindValue(':showDeprecatedPages', isset($submitValues['show_deprecated_pages']) ? 1 : 0, PDO::PARAM_STR);
-    $stmt->bindValue(':contactId', $contactId, PDO::PARAM_INT);
-    $stmt->execute();
+    try {
+        $stmt = $pearDB->prepare($rq);
+        $stmt->bindValue(':contactName', $submitValues['contact_name'], PDO::PARAM_STR);
+        $stmt->bindValue(':contactAlias', $submitValues['contact_alias'], PDO::PARAM_STR);
+        $stmt->bindValue(':contactLang', $submitValues['contact_lang'], PDO::PARAM_STR);
+        $stmt->bindValue(
+            ':contactEmail',
+            ! empty($submitValues['contact_email']) ? $submitValues['contact_email'] : null,
+            PDO::PARAM_STR
+        );
+        $stmt->bindValue(
+            ':contactPager',
+            ! empty($submitValues['contact_pager']) ? $submitValues['contact_pager'] : null,
+            PDO::PARAM_STR
+        );
+        $stmt->bindValue(
+            ':contactAutologinKey',
+            ! empty($submitValues['contact_autologin_key']) ? $submitValues['contact_autologin_key'] : null,
+            PDO::PARAM_STR
+        );
+        $stmt->bindValue(
+            ':contactLocation',
+            ! empty($submitValues['contact_location']) ? $submitValues['contact_location'] : null,
+            PDO::PARAM_INT
+        );
+        $stmt->bindValue(
+            ':defaultPage',
+            ! empty($submitValues['default_page']) ? $submitValues['default_page'] : null,
+            PDO::PARAM_INT
+        );
+        $stmt->bindValue(':showDeprecatedPages', isset($submitValues['show_deprecated_pages']) ? 1 : 0, PDO::PARAM_STR);
+        $stmt->bindValue(':contactId', $userIdConnected, PDO::PARAM_INT);
+        $stmt->execute();
+    } catch (PDOException $e) {
+        throw new RepositoryException(
+            message: 'Unable to update contact from my account for contact id ' . $userIdConnected,
+            context: ['userIdConnected' => $userIdConnected],
+            previous: $e
+        );
+    }
 
-    if (isset($submitValues['contact_passwd']) && ! empty($submitValues['contact_passwd'])) {
+    if (isset($submitValues['contact_passwd']) && $submitValues['contact_passwd'] !== '') {
         $hashedPassword = password_hash($submitValues['contact_passwd'], CentreonAuth::PASSWORD_HASH_ALGORITHM);
 
         try {
             $contact = new CentreonContact($pearDB);
-            $contact->renewPasswordByContactId($contactId, $hashedPassword);
+            $contact->renewPasswordByContactId($userIdConnected, $hashedPassword);
 
             $centreon->user->setPasswd($hashedPassword);
 
             LoggerPassword::create()->success(
-                initiatorId: (int) $centreon->user->get_id(),
-                targetId: (int) $centreon->user->get_id(),
+                initiatorId: $userIdConnected,
+                targetId: $userIdConnected,
             );
         } catch (PDOException $e) {
             LoggerPassword::create()->warning(
                 reason: 'password update failed',
-                initiatorId: (int) $centreon->user->get_id(),
-                targetId: (int) $centreon->user->get_id(),
+                initiatorId: $userIdConnected,
+                targetId: $userIdConnected,
                 exception: $e
             );
 
             throw new RepositoryException(
-                message: 'Unable to update password for contact id ' . $contactId,
+                message: 'Unable to update password from my account for contact id ' . $userIdConnected,
+                context: ['userIdConnected' => $userIdConnected],
                 previous: $e
             );
         }
@@ -220,6 +238,8 @@ function updateContact($contactId = null): void
 /**
  * @param array<string,mixed> $fields
  *
+ * @throws InvalidArgumentException
+ *
  * @return array<string,string>|true
  */
 function validatePasswordModification(array $fields): array|bool
@@ -228,7 +248,12 @@ function validatePasswordModification(array $fields): array|bool
     $newPassword = $fields['contact_passwd'];
     $confirmPassword = $fields['contact_passwd2'];
     $currentPassword = $fields['current_password'];
-    $contactId = (int) $centreon->user->get_id();
+
+    $userIdConnected = (int) $centreon->user->get_id();
+
+    if (! $userIdConnected > 0) {
+        throw new InvalidArgumentException('Invalid connected user ID provided for password modification validation');
+    }
 
     // If the user does not want to change his password, we do not need to check it
     if (empty($newPassword) && empty($confirmPassword) && empty($currentPassword)) {
@@ -239,8 +264,8 @@ function validatePasswordModification(array $fields): array|bool
     if (empty($newPassword) && ! empty($confirmPassword) && empty($currentPassword)) {
         LoggerPassword::create()->warning(
             reason: 'new password or current password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $centreon->user->get_id(),
+            initiatorId: $userIdConnected,
+            targetId: $userIdConnected,
         );
 
         return ['contact_passwd2' => _('Please fill in all password fields')];
@@ -250,8 +275,8 @@ function validatePasswordModification(array $fields): array|bool
     if (empty($newPassword) && ! empty($currentPassword)) {
         LoggerPassword::create()->warning(
             reason: 'new password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $centreon->user->get_id(),
+            initiatorId: $userIdConnected,
+            targetId: $userIdConnected,
         );
 
         return ['current_password' => _('Please fill in all password fields')];
@@ -261,8 +286,8 @@ function validatePasswordModification(array $fields): array|bool
     if (! empty($newPassword) && empty($currentPassword)) {
         LoggerPassword::create()->warning(
             reason: 'current password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $centreon->user->get_id(),
+            initiatorId: $userIdConnected,
+            targetId: $userIdConnected,
         );
 
         return ['current_password' => _('Please fill in all password fields')];
@@ -272,8 +297,8 @@ function validatePasswordModification(array $fields): array|bool
     if (! empty($currentPassword) && password_verify($currentPassword, $centreon->user->passwd) === false) {
         LoggerPassword::create()->warning(
             reason: 'current password wrong',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $centreon->user->get_id(),
+            initiatorId: $userIdConnected,
+            targetId: $userIdConnected,
         );
 
         return ['current_password' => _('Authentication failed')];
@@ -281,14 +306,14 @@ function validatePasswordModification(array $fields): array|bool
 
     try {
         $contact = new CentreonContact($pearDB);
-        $contact->respectPasswordPolicyOrFail($newPassword, $contactId);
+        $contact->respectPasswordPolicyOrFail($newPassword, $userIdConnected);
 
         return true;
     } catch (Exception $e) {
         LoggerPassword::create()->warning(
             reason: 'new password does not respect password policy',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $centreon->user->get_id(),
+            initiatorId: $userIdConnected,
+            targetId: $userIdConnected,
             exception: $e,
         );
 
@@ -298,25 +323,46 @@ function validatePasswordModification(array $fields): array|bool
 
 /**
  * @param array<string,mixed> $fields
- * @return array<string,string>|bool
+ *
+ * @throws RepositoryException
+ * @throws InvalidArgumentException
+ *
+ * @return array<string,string>|true
  */
-function checkAutologinValue(array $fields)
+function checkAutologinValue(array $fields): array|bool
 {
     global $pearDB, $centreon;
     $errors = [];
 
-    if (!empty($fields['contact_autologin_key'])) {
-        $contactId = $centreon->user->get_id();
-        $statement = $pearDB->prepare(
-            'SELECT * FROM `contact_password` WHERE contact_id = :contactId ORDER BY creation_date DESC LIMIT 1'
-        );
-        $statement->bindValue(':contactId', $contactId, \PDO::PARAM_INT);
-        $statement->execute();
+    if (! empty($fields['contact_autologin_key'])) {
 
-        if (
-            ($result = $statement->fetch(\PDO::FETCH_ASSOC))
-            && password_verify($fields['contact_autologin_key'], $result['password'])
-        ) {
+        $userIdConnected = (int) $centreon->user->get_id();
+
+        if (! $userIdConnected > 0) {
+            throw new InvalidArgumentException('Invalid connected user ID provided for autologin key check');
+        }
+
+        $query = <<<'SQL'
+            SELECT * FROM `contact_password`
+            WHERE contact_id = :contactId
+            ORDER BY creation_date DESC
+            LIMIT 1
+            SQL;
+
+        try {
+            $contactPassword = $pearDB->fetchAssociative(
+                $query,
+                QueryParameters::create([QueryParameter::int('contactId', $userIdConnected)])
+            );
+        } catch (ValueObjectException|CollectionException|ConnectionException $e) {
+            throw new RepositoryException(
+                message: 'Unable to fetch contact password for contact id ' . $userIdConnected,
+                context: ['userIdConnected' => $userIdConnected],
+                previous: $e
+            );
+        }
+
+        if (password_verify($fields['contact_autologin_key'], $contactPassword['password'])) {
             $errors['contact_autologin_key'] = _('Your autologin key must be different than your current password');
         } elseif (
             !empty($fields['contact_passwd'])
@@ -328,20 +374,20 @@ function checkAutologinValue(array $fields)
 
             LoggerPassword::create()->warning(
                 reason: 'new password and autologin key are the same',
-                initiatorId: (int) $centreon->user->get_id(),
-                targetId: (int) $centreon->user->get_id(),
+                initiatorId: $userIdConnected,
+                targetId: $userIdConnected,
             );
         }
     }
 
     return count($errors) > 0 ? $errors : true;
 }
-function updateNonLocalContactInDB($contact_id = null): void
+function updateNonLocalContactByMyAccountInDB($userIdConnected = null): void
 {
     global $pearDB, $centreon, $form;
 
-    if (! $contact_id){
-        return ;
+    if (! $userIdConnected) {
+        return;
     }
     $ret = $form->getSubmitValues();
     $ret['contact_pager'] = !empty($ret['contact_pager']) ?
@@ -371,9 +417,9 @@ function updateNonLocalContactInDB($contact_id = null): void
         \PDO::PARAM_INT
     );
 
-    $stmt->bindValue(':defaultPage', !empty($ret['default_page']) ? $ret['default_page'] : null, \PDO::PARAM_INT);
-    $stmt->bindValue(':showDeprecatedPages', isset($ret['show_deprecated_pages']) ? 1 : 0, \PDO::PARAM_STR);
-    $stmt->bindValue(':contactId', $contact_id, \PDO::PARAM_INT);
+    $stmt->bindValue(':defaultPage', ! empty($ret['default_page']) ? $ret['default_page'] : null, PDO::PARAM_INT);
+    $stmt->bindValue(':showDeprecatedPages', isset($ret['show_deprecated_pages']) ? 1 : 0, PDO::PARAM_STR);
+    $stmt->bindValue(':contactId', $userIdConnected, PDO::PARAM_INT);
     $stmt->execute();
     $stmt->closeCursor();
 
