@@ -71,11 +71,8 @@ $currentServerMicroTime = $sDate->getTimestamp();
 $path = "./include/views/graphs/";
 
 
-/*
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
 
 
 $defaultGraphs = array();
